pub struct BufferLiveness {
pub first_appearance: usize,
pub last_appearance: usize,
pub pool_key: BufferPoolKey,
pub prototype: Buffer,
}Expand description
Liveness information for a buffer.
Fields
first_appearance: usizeIndex of first schedule step that uses this buffer.
last_appearance: usizeIndex of last schedule step that uses this buffer.
pool_key: BufferPoolKeyPool key for buffer grouping.
prototype: BufferRepresentative logical buffer for this allocation ID.