pub struct ReuseDependency {
pub predecessor_step: usize,
pub successor_step: usize,
}Expand description
Schedule-order dependency introduced by a physical buffer reuse.
Fields
predecessor_step: usizeSchedule item that last uses the old logical buffer occupying the storage.
successor_step: usizeSchedule item that first uses the new logical buffer reusing that storage.